==> OpenInteract-1.99_00.tar.gz: base_page-2.04/OpenInteract2/Action/PageScan.pm <==
package OpenInteract2::Action::PageScan;

# $Id: PageScan.pm,v 1.3 2003/06/09 11:46:58 lachoy Exp $

use strict;
use base qw( OpenInteract2::Action );
use OpenInteract2::Constants qw( :log );
use OpenInteract2::Context   qw( CTX DEBUG LOG );
use OpenInteract2::PageScan;

$OpenInteract2::Action::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);

sub display {
    my ( $self ) = @_;
    return $self->generate_content(
                    {}, { name => 'base_page::page_scan_form' } );
}

sub run {
    my ( $self ) = @_;
    my $scan_dir = CTX->request->param( 'scan_directory' );

    my $scanner = OpenInteract2::PageScan->new({ file_root => $scan_dir,
                                                 DEBUG     => DEBUG });
    my $new_files = $scanner->find_new_files;
    my @pages  = ();
    my @errors = ();

    foreach my $location ( @{ $new_files } ) {
        my $file_info = $scanner->get_file_info( $location );
        DEBUG && LOG( LDEBUG, "Trying to add file [$location] ",
                              "[$file_info->{mime_type}]" );
        my $page = eval { $scanner->add_location( $location, $file_info ) };
        if ( $@ ) {
            push @errors, { error => "$@", location => $location };
        }
        else {
            push @pages, $page if ( $page );
        }
    }
    return $self->generate_content(
                    { page_list  => \@pages,
                      error_list => \@errors },
                    { name => 'base_page::page_scan_results' } );
}

1;

==> OpenInteract-1.99_03.tar.gz: base_page-2.12/OpenInteract2/Action/PageScan.pm <==
package OpenInteract2::Action::PageScan;

# $Id: PageScan.pm,v 1.4 2003/06/25 14:10:49 lachoy Exp $

use strict;
use base qw( OpenInteract2::Action );
use Log::Log4perl            qw( get_logger );
use OpenInteract2::Constants qw( :log );
use OpenInteract2::Context   qw( CTX );
use OpenInteract2::PageScan;

$OpenInteract2::Action::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);

sub display {
    my ( $self ) = @_;
    return $self->generate_content(
                    {}, { name => 'base_page::page_scan_form' } );
}

sub run {
    my ( $self ) = @_;
    my $log = get_logger( LOG_APP );

    my $scan_dir = CTX->request->param( 'scan_directory' );

    my $scanner = OpenInteract2::PageScan->new({ file_root => $scan_dir,
                                                 DEBUG     => $log->is_debug });
    my $new_files = $scanner->find_new_files;
    my @pages  = ();
    my @errors = ();

    foreach my $location ( @{ $new_files } ) {
        my $file_info = $scanner->get_file_info( $location );
        $log->is_debug &&
            $log->debug( "Trying to add file [$location] ",
                         "[$file_info->{mime_type}]" );
        my $page = eval { $scanner->add_location( $location, $file_info ) };
        if ( $@ ) {
            push @errors, { error => "$@", location => $location };
        }
        else {
            push @pages, $page if ( $page );
        }
    }
    return $self->generate_content(
                    { page_list  => \@pages,
                      error_list => \@errors },
                    { name => 'base_page::page_scan_results' } );
}

1;
